# Medchem CLI

Medchem proposes CLI commands in order to filter directly from file paths. CSV, JSON, Excel, Parquet and SDF are supported.

Available commands can be found with:

```bash
medchem --help
```

To know more about one specific command:

```bash
medchem common-alerts --help
```
